function dist = distfu(w,f)
% DISTFU Verteilungsfunktion.
% DISTFU berechnet Zwischenwerte der Verteilungsfunktion zwischen den 
% Sttzstellenwerten w, soda eine Verteilung entsteht, die man gut plotten
% kann.
%
% Eingabeparameter:
%   w ... Geschwindigkeitssttzstellenvektor
%   f ... Verteilungsfunktion an diesen Sttzstellen 
%
% Ergebnis:
%   dist ... Matrix, die in der ersten Spalte Geschwindigkeiten und in der
%            zweiten  die dazugehrigen Werte der Verteilungsfunktion 
%            enthlt 
% 

% Dimensioniere Ergebnismatrix; es soll die Verteilungsfunktion an 200
% Punkten berechnet werden, soda man sie schn plotten kann.
dist = zeros(200,2);

% Anzahl der Sttzstellen
N = length(w);

% fr interne Berechnungen mu der Sttzstellenvektor w um einen Eintrag
% erweitert werden (ist so, tut hier nichts weiter zur Sache)
wext = zeros(N+1,1);
wext(1:N) = w;
wext(N+1) = sqrt(2).*sqrt(50);

% Berechnung der Verteilungsfunktion an 200 Stellen zwischen v=0 und
% v=wext(N+1); 
step = wext(N+1)./199;
dist(:,1) = (0:step:wext(N+1))';
for count = 1:200
   % das Ergebnis mu mit v^2 multipliziert werden, um den bekannten
   % "Maxwellschwanz" zu erhalten
   dist(count,2) = dist(count,1).^2.*onepoint(dist(count,1),wext,f);
end


%-----------------------------------------------------------------------------%
% Lokale function

function value = onepoint(v,w,f)
% Berechnung der Verteilungsfunktion an einer Stelle v unter Verwendung des
% Sttzstellenvektors w (das mu schon der erweiterte sein)

N = length(w)-1;
value = 0;
for k=1:1:N
  if (v >= w(k)) & (v <= w(k+1))
    chiiv = (w(k+1)-v)./(w(k+1)-w(k));
  elseif ((k>1)&(v >= w(k-1))) & (v <= w(k))
    chiiv = (v-w(k-1))./(w(k)-w(k-1));
  else
    chiiv = 0;
  end
  value = value + f(k).*chiiv;
end





 