close all;
clear all;

%-----------------------------------------------------------------------------%
% Berechnung des Relaxationsprozesses
%-----------------------------------------------------------------------------%

% Laden der Daten
C = load('C.dat');
anf = load('anf.dat');

% Extrahiere Geschwindigkeitssttzstellenvektor und Anfangswerte der
% Verteilungsfunktion an diesen Stellen aus der Matrix anf
stuetz = anf(:,1);
fanf = anf(:,2);

% Anzahl der Sttzstellen
N=length(fanf);


% Zeitschritte
tanz = 50;
tmax = 0.2;
tstep = tmax./(tanz-1);

% Berechne die Matrix-Exponentialfunktion expm(tstep*C) -> Evolutionsmatrix
evolm = expm(tstep.*C);

% Berechne die Entwicklung der Verteilungsfunktion ausgehend von der
% Anfangsverteilung, speichere die Ergebnisse fr jeden Zeitschritt
fnew = fanf;
for count=0:tanz-1
  
  % speichere die Anfangsverteilung plotte sie und speichere sie
  if count == 0
    % Zwischenwerte berechnen
    vert = distfu(stuetz,fnew);
    % lege eine Matrix an, in der alle Ergebnisse gespeichert sind;
    % in der ersten Spalte stehen die Geschwindigkeiten und in den
    % weiteren Spalten die Werte der Verteilungsfunktion fr jeden
    % Zeitsschritt; in der letzten Spalte soll die Maxwellverteilung
    % Platz finden
    erg = zeros(length(vert(:,1)),tanz+2);
    erg(:,1) = vert(:,1);
    erg(:,2) = vert(:,2);
    plot(vert(:,1),vert(:,2),'r','Linewidth',2);
    xlabel('Geschwindigkeit');
    ylabel('Verteilungsfunktion');
    title('Relaxationsproze');
    drawnow;
    % weitere Verteilungen sollen in dasselbe Bild geplottet werden
    hold on;
  else
    % Berechne f(t+tstep)=expm(tstep*C).f(t)
    fnew = evolm*fnew;
    vert = distfu(stuetz,fnew);
    % dazuplotten
    plot(vert(:,1),vert(:,2));
    drawnow;
    % Ergebniss in Matrix erg dazuschreiben
    erg(:,count+2) = vert(:,2);
  end

end

  
% plotte Maxwellverteilung an den selben Geschwindigkeitsstellen wie 
% die anderen Verteilungen

vstep = max(vert(:,1))./(length(vert(:,1))-1);
v = (0:vstep:max(vert(:,1)))';
n = 27.8609;
T = 3;
k = 1;
m = 1;

maxw = (4./sqrt(pi)).*(m./(2.*k.*T))^(3./2).*n.*v.^2.* ...
        exp(-(m.*v.^2)./(2.*k.*T));

% dazuplotten
plot(v,maxw,'-r','Linewidth',2);
% in Matrix erg dazuschreiben
erg(:,tanz+2) = maxw;

% berschreiben wieder ausschalten
hold off;

%-----------------------------------------------------------------------------%
% Erzeugen eines Movies mittels der Matrix erg
%-----------------------------------------------------------------------------%

for count=0:50
  % bei der Anfangsverteilung treten die grten y-Werte auf -> ermittle
  % deren x,y-Bereich, um ihn fr alle weiteren plots zu fixieren
  % Bei movies mu jeder plot denselben Achsenbereich haben, sonst
  % "springen" die Achsen im Movie!
  if count == 0
    area(erg(:,1),erg(:,2));
    xrange = get(gca,'XLim');
    yrange = get(gca,'YLim');
    title('Relaxationsproze');
    xlabel('Geschwindigkeit');
    ylabel('Verteilungsfunktion');
    M(count+1) = getframe;
  else
    area(erg(:,1),erg(:,count+2));
    axis([xrange yrange]);
    title('Relaxationsproze');
    xlabel('Geschwindigkeit');
    ylabel('Verteilungsfunktion');
    M(count+1) = getframe;
  end
end

movie(M,3);

