function [x,y,z] = func2d(n,xi,yi,a)
% Die Funktion func2d berechnet
%
% $$\sum_{i=0}^{n} \sum{j=0}^{i} a_{i,j} x^{i-j} y^{j}$$,
%
% wobei die Konstanten a in einem Zeilenvektor gespeichert sind.
%
% n=0: a(1)
% n=1: a(1) + a(2)*x + a(3)*y
% n=2: a(1) + a(2)*x + a(3)*y + a(4)*x^2 + a(5)*x*y + a(6)*y^2
% n=3: a(1) + a(2)*x + a(3)*y + a(4)*x^2 + a(5)*x*y + a(6)*y^2 +
%             a(7)*x^3 + a(8)*x^2*y + a(9)*x*y^2 + a(10)*y^3
% n=4: continued
%
% Input:  Maximale Ordnung n
%         Vektoren x und y
%         Konstantenvektor a    
% Output: x, y, Funktion z(x,y)
%
% Autor:  Winfried Kernbichler
% Datum:  5.11.1999 

% Definition der Defaultwerte
if ( nargin < 1 ), n = 2; end
if ( nargin < 2 ), x = -1:0.1:1; else x = xi; end
if ( nargin < 3 ), y = -1:0.1:1; else y = yi; end

% Sicherstellen, dass n eine Integer Grsse ist
n = floor(n);
% Anzahl der mglichen additiven Terme in der Funktion
nv = (n+1)*(n+2)/2;

% Definition der Defaultwerte fr a
if ( nargin < 4 ), 
   a = zeros(1,nv); 
   a(nv-n:nv) = ones(1,n+1);
end

% berprfung des Vektors a mit den Konstanten auf die
% richtige Lnge nv
la = length(a);
if ( la < nv ) 
   a(la+1:nv) = zeros(1,nv-la); 
elseif ( la > nv )
   a(nv+1:la) = [];
end

% Erzeugen des Gitternetzes aus den beiden Vektoren x und y
[xx,yy] = meshgrid(x,y);

% Umwandlung der Gitternetze in einen Zeilenvektor der Lnge len
% Alle x und y Werte befinden sich dabei in einer Zeile
len = prod(size(xx));
lx = reshape(xx,1,len);
ly = reshape(yy,1,len);
% Replizieren der Zeilenvektoren, damit entsteht jeweils eine 
% Matrix der Dimension (nv len) mit jeweils gleichen Zeilen. 
mx = repmat(lx,nv,1);
my = repmat(ly,nv,1);

% Erzeugung von Spaltenvektoren mit den jeweiligen Potenzen und
% und Replizierung damit fr die Potenzen ebenfalls eine 
% Matrix der Dimension (nv len) mit jeweils gleichen Spalten
% entsteht.
tnx = ( repmat([0:n],n+1,1) - repmat([0:n]',1,n+1) );
nx  = repmat( tnx(tnx>=0), 1, length(lx) );
tny = ( repmat([0:n],n+1,1) .* ( 2*tril(ones(n+1))-1 ) )';
ny  = repmat( tny(tny>=0), 1, length(ly) );

% Bilden der richtigen Potenzen, Multiplikation mit den jeweiligen
% Konstanten und Summation unter Ausnutzung der Regeln fr die 
% Matrizenmultiplikation. 
% Rckfhrung der Matrix in die richtige Form (wie xx)
z = reshape( a*(mx.^nx .* my.^ny), size(xx) );
