function handletest()

% Example for various features of Matlab graphics and uicontrol

echo off
clear m n x legpol legpola ax2
global m n x legpol legpola

% Initial Settings
n = 2;
m = 1;
x = [-1:0.001:1];
legpol = legval(n,x);
legpola = legzval(n,x);
nmin=0;
nmax=20;

% Start the first figure
figure(1)
fig1 = clf;
set(fig1,'Name','Legendre Polynomials')
set(fig1,'Resize','off')
set(fig1,'Position',[50 100 600 400])
set(fig1,'Tag','figure1')

% Introduce Menue Entries
menu1 = uimenu('Parent',fig1, ...
	'Label','Graphics', ...
	'Tag','menu1');
menu11 = uimenu('Parent',menu1, ...
	'Callback','handlesub menu11', ...
	'Label','Grid off', ...
	'Tag','menu11');
menu12 = uimenu('Parent',menu1, ...
	'Callback','handlesub menu12', ...
	'Label','Axis off', ...
	'Tag','menu12');

% Make the first plot
axes('Parent',fig1,'position',[0.1 0.6 0.6 0.3])
ax1 = gca;
plot(x,legpol,'Parent',ax1,'Tag','line1')
hold on
plot(x,legpol,'Parent',ax1,'Tag','line1t')
hold off

title(strcat('Legendre Polynomial of Order n=',int2str(n)))
xlabel('x')
ylabel('P_{n}(x)')
lh1 = findobj('Tag','line1');
set(lh1,'LineWidth',1,'Color','red')
set(ax1,'XGrid','on')
set(ax1,'ButtonDownFcn','handlesub zoom')
set(ax1,'YGrid','on')
set(ax1,'Tag','ax1')

% Make the second plot
axes('Parent',fig1,'position',[0.1 0.1 0.6 0.3])
ax2 = gca;
plot(x,legpola(m+1,:),'Parent',ax2,'Tag','line2')
hold on
plot(x,legpola(m+1,:),'Parent',ax2,'Tag','line2t')
hold off
title(strcat('Ass. Legendre Functions with m=',int2str(m)))
xlabel('x')
ylabel('P_{n}^{m}(x)')

lh2 = findobj('Tag','line2');
set(lh2,'LineWidth',1)
set(ax2,'ButtonDownFcn','handlesub tang')
set(ax2,'XGrid','on')
set(ax2,'YGrid','on')
set(ax2,'Tag','ax2')

% Slider Control
% First slider for n
figure(fig1)
slider1 = uicontrol( ...
   'Style','slider', ...
   'Tag','slider1', ...
   'Min',0,'Max',20, ...
   'Value',n, ...
   'SliderStep',[0.05 0.1], ...
   'String','Order', ...
   'Callback','handlesub slider1', ...
   'Units','normalized', ...
   'Position',[0.75 0.6 0.2 0.05] ...
   );

% Text for first slider
text1 = uicontrol( ...
    'Tag','text1', ...
    'Style','text', ...
    'String','Parameter n', ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.75 0.64 0.3 0.06] ...
    );
text1min = uicontrol( ...
    'Tag','text1min', ...
    'Style','text', ...
    'String',int2str(nmin), ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.75 0.53 0.06 0.06] ...
    );
text1max = uicontrol( ...
    'Tag','text1max', ...
    'Style','text', ...
    'String',int2str(nmax), ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.88 0.53 0.06 0.06] ...
    );
 
% Second slider for m
slider2 = uicontrol( ...
   'Style','slider', ...
   'Tag','slider2', ...
   'Min',0,'Max',n, ...
   'Value',m, ...
   'SliderStep',[0.05 0.1], ...
   'String','Order', ...
   'Callback','handlesub slider2', ...
   'Units','normalized', ...
   'Position',[0.75 0.1 0.2 0.05] ...
   );

handlesub('slider1');
handlesub('slider2');

% Text for second slider
text2 = uicontrol( ...
    'Tag','text2', ...
    'Style','text', ...
    'String','Parameter m', ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.75 0.14 0.3 0.06] ...
    );
text2min = uicontrol( ...
    'Tag','text2min', ...
    'Style','text', ...
    'String',int2str(nmin), ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.75 0.03 0.06 0.06] ...
    );
text2max = uicontrol( ...
    'Tag','text2max', ...
    'Style','text', ...
    'String',int2str(n), ...
    'FontSize',9, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units','normalized', ...
    'Position',[0.88 0.03 0.06 0.06] ...
    );
 
% Second EditBox for m
edit2 = uicontrol( ...
   'Style','edit', ...
   'Tag','edit2', ...
   'Min',0,'Max',1, ...
   'String',num2str(m), ...
   'Callback','handlesub edit2', ...
   'BackgroundColor',[1 1 1], ...
   'Units','normalized', ...
   'Position',[0.75 0.16 0.06 0.045] ...
   );



% First Editbox for n
edit1 = uicontrol( ...
   'Style','edit', ...
   'Tag','edit1', ...
   'Min',0,'Max',1, ...
   'String',num2str(n), ...
   'Callback','handlesub edit1', ...
   'BackgroundColor',[1 1 1], ...
   'Units','normalized', ...
   'Position',[0.75 0.66 0.06 0.045] ...
   );


