% Beispiel fr die Verwendung von fminsearch, fzero, quad8
% 
% Minimieren einer Funktion zum Fitten (Least Squares Method) 
% Modellfunktion: y = ( a*log(x+1) - b*x ) .* exp(-c*x)
%
% Finden von Nullstellen  
% Integration
%
% Autor: Winfried Kernbichler 12.12.1999

% Bereiche und Strke des Rauschens
xsta = 0;
xend = 20;
xdel = 0.1;
rauschl = 0.1;
xdata=[xsta:xdel:xend];
rausch=rauschl.*randn(1,length(xdata));

% Generieren von verrauschten Messdaten 
ad = 3; bd = 0.4; cd = 0.1;
parad = [ad,bd,cd];
ydata = modell(xdata,parad) + rausch;

% Plotten der 'Medaten'
fig1 = figure(1); clf;
plot(xdata,ydata,'k');
hold on;

% fitten mit nichtlinearer Modellfunktion
% Modellfunktion: y = ( a*log(x+1) - b*x ) .* exp(-c*x)
% 'geratene' Startwerte Parameter a, b und c 
para0=[2.5 0.5 0.2];

fmins_opt = optimset('Display','final','TolX',1.e-8,'TolFun',1.e-8);
t0 = cputime;
paraf = fminsearch('modelllq',para0,fmins_opt,xdata,ydata);
timef = cputime - t0;
% paraf = fminsearch('modelllq',para0,[],xdata,ydata) % ohne Optionen

% Methode aus Statistics Toolbox
% Empfindlich auf die Wahl der Anfangsparamter
t0 = cputime;
paran=nlinfit(xdata,ydata,'modellnl',[2.6 0.35 0.15]);
timen = cputime - t0;

% Methode aus der Optimization Toolbox
t0 = cputime;
paral = lsqcurvefit('modellnl',para0,xdata,ydata);
timel = cputime - t0;

% Korrelationskoeffizienten
ycf = corrcoef(ydata,modell(xdata,paraf));
ycn = corrcoef(ydata,modell(xdata,paran));
ycl = corrcoef(ydata,modell(xdata,paral));

% Polynomfit vierten Grades zum Vergleich
pol = polyfit(xdata,ydata,4);
ycp = corrcoef(ydata,polyval(pol,xdata));

% Wurzel aus der Summe der Abstandsquadrate durch Anzahl der Datenpunkte
avdf = sqrt ( sum ( (ydata - modell(xdata,paraf)).^2 ) / length(xdata) );
avdn = sqrt ( sum ( (ydata - modell(xdata,paran)).^2 ) / length(xdata) );
avdl = sqrt ( sum ( (ydata - modell(xdata,paral)).^2 ) / length(xdata) );
avdp = sqrt ( sum ( (ydata - polyval(pol,xdata)).^2  ) / length(xdata) );

% Gefittetes Ergebnis
plot(xdata,modell(xdata,paraf),'-r');
plot(xdata,modell(xdata,paran),':r');
plot(xdata,polyval(pol,xdata),'b');
legend('data','lq fit','nl fit','pol fit',0);
grid on;
hold off;

% Ausgabe am Schirm
disp('Nichtlineares Fitten'); disp(' ');
disp('Original Parameter');
disp(parad);
disp('Startwerte');
disp(para0);
disp('Fit Parameter - fminsearch');
disp(paraf);
disp('Fit Parameter - nlinfit');
disp(paran');
disp('Fit Parameter - lsqcurvefit');
disp(paral);
disp('Zeiten: fmins nlinfit lsqcurvefit');
disp([timef,timen,timel]);
disp('Mittlerer Abstand: fmins nlinfit lsqcurvefit polynom');
disp([avdf,avdn,avdl,avdp]);
disp('Korrelationskoeffizient: fmins nlinfit lsqcurvefit polynom');
disp([ycf(2,1),ycn(2,1),ycl(2,1),ycp(2,1)]);

disp(' '); disp('PAUSE MODE'); pause;

% Plotten eines greren Bereichs
fig2 = figure(2); clf;
plot(xdata,ydata,'k');
hold on;

xendn = 30;
xdatan = [xsta:xdel:xendn];
plot(xdatan,modell(xdatan,paraf),'-r');
plot(xdatan,modell(xdatan,paran),'-r');
plot(xdatan,polyval(pol,xdatan),'b');
legend('data','lq fit','nl fit','pol fit',0);


% Bestimmung von Nullstellen - MATLAB function fzero
% Optionen fr fzero: z.B.: TolX: Genauigkeit in x-Richtung
fzero_opt = optimset('Display','final','TolX',1.e-8);
xzero(1) = fzero('modell',[-0.9 1],fzero_opt,paraf);
xzero(2) = fzero('modell',[10 30],fzero_opt,paraf);
yzero = modell(xzero,paraf);
plot(xzero,yzero,'o');

grid on;
hold off;

% Integration zwischen den Nullstellen
% Integration - MATLAB function quad oder quad8
reltol = 1.e-6; % Relative Genauigkeit
% [] steht fr keine Angabe, stattdessen kann man 'trace' einfgen,
% dann plottet Matlab eine Kurve mit allen verwendeten Datenpunkten.
area  = quad8('modell',xzero(1),xzero(2),reltol,[],paraf);

disp('Nullstellen');
disp(xzero);
disp('Flche zwischen den Nullstellen:')
disp(area);

disp(' '); disp('PAUSE MODE'); pause;

% Kleinerer Auschnitt
% Vergleich mit Spline durch Datenpunkte

% Funktion berechnet Spline Koeffizienten, die mit 
% ppval ausgewertet werden knnen.
sd = spline(xdata,ydata);
ind1 = 1;
ind2 = 10;
xdet = linspace(xdata(ind1),xdata(ind2),200);


fig3 = figure(3); clf;
plot(xdata(ind1:ind2),ydata(ind1:ind2),'ko');
hold on
plot(xdet,modell(xdet,paraf),'-r');
plot(xdet,polyval(pol,xdet),'b');
plot(xdet,ppval(sd,xdet),'g'); % ppval wertet Splinedaten aus
legend('data','nl fit','pol fit','cubic spline',0);
grid on;
hold off

disp(' '); disp('PAUSE MODE'); pause;

% Vergleich von Residuals fr den Least Squares Fit und den Polynomfit
fig4 = figure(4); clf;
res  = ydata - modell(xdata,paraf);
resp = ydata - polyval(pol,xdata);

subplot(2,1,1);
stem(xdata,res,'filled');
title('Non-linear Fit');
subplot(2,1,2);
stem(xdata,resp,'r');
title('Polynomial Fit');

disp(' '); disp('PAUSE MODE - ZUM BEENDEN EINE TASTE DRCKEN'); pause;
close(fig1);
close(fig2);
close(fig3);
close(fig4);

