% Kurvenanpassung mit Hilfe linearer Koeffizienten
% Beispiele: Ellipse, Kreis, Parabel, Hyperbel
%
% Autor: Winfried Kernbichler    09.01.2000
%
% Bentigte Programme:  quadgl
% Bentigte Datenfiles: ellip.dat, kreis.dat, parab.dat, hyperb.dat
echo off; clc; % Kein Echo; Lschen des Schirms
disp(' ');
disp('Kurvenanpassung mit Hilfe linearer Koeffizienten');
disp('Beispiele: Ellipse, Kreis, Parabel, Hyperbel');
disp('Autor: Winfried Kernbichler    09.01.2000');
disp(' ');

% Interaktive Eingabe der Filenamen und des Drehwinkels.
% Zuweisen von Defaultwerten, wenn nichts bergeben wird.
disp('Eingabe des Filenamens ohne extension:');
disp(' Mglichkeit: ellip, kreis, parab, hyperb');
disp(' Defaultwert: ellip');
fname = input(' Filename?    ','s'); 
% 's' teilt mit, dass ein String erwartet wird.
if isempty(fname), fname = 'ellip'; end 
% isempty liefert 1(true) wenn nichts bergeben wird.
disp(' ');
disp('Drehung des Koordinatensystems');
disp(' Defaultwert:     0 Grad');
alphai = input(' Winkel in Grad?  ');
if isempty(alphai); alphai = 0; end
alpha = alphai*pi/180;
clc;

% Laden der Daten von Files
data = load([fname,'.dat']);
disp(['Datenfile:  ',[fname,'.dat']]); disp(' ');
disp(['Drehwinkel: ',num2str(alphai),'  Grad']); disp(' ');
xdo = data(:,1); % Zuweisung der x- und 
ydo = data(:,2); % y-Daten zu Spaltenvektoren

% Drehung des Koordinatensystems um mit wenigen Datenfiles mehr Flle testen zu knnen.
xd = xdo*cos(alpha) - ydo*sin(alpha);
yd = xdo*sin(alpha) + ydo*cos(alpha);

% Plotten der Daten
fig1 = figure(1); clf;
plot(xd,yd,'or');

% Erstellung der Matrix fr das Gleichungssystem X*S = V
% Das konstante Glied der Gleichung fr die Kegelschnitte wurde dabei in den Vektor
%  auf rechten Seite des Gleichungssystems verlagert.
X = [xd.^2, 2*xd.*yd, yd.^2, 2*xd, 2*yd];
% Vektor auf der rechten Seite des Gleichungssystems (konstantes Glied)
%  Willkrlich: A(3,3) = 1
V = - ones(size(xd));
% Lsen des Gleichungssystems im Sinne der Least Squares Methode 
%  mit Hilfe des Backslash-Operators (Matrix Left Division)
S = X \ V;
% Der Lsungsvektor S enthlt die 5 unbekannten Koeffizienten

% Zuweisen des Lsungsvektors in die Koeffizientenmatrix A
A = zeros(3); % Legt Gre fest
A(1,1) = S(1);
A(1,2) = S(2); A(2,1) = S(2);
A(2,2) = S(3); 
A(1,3) = S(4); A(3,1) = S(4);
A(2,3) = S(5); A(3,2) = S(5);
A(3,3) = 1;

% Berechnung der Determinante und der Unterdeterminante
% Wegen Rundungsfehlern ergibt sich bei numerischen Berechnungen selten eine exakte Null,
% daher werden beide auf Null gesetzt, wenn der Wert unter der Genauigkeitsgrenze eps liegt.
D = det(A); if abs(D) < eps, D = 0; end
D33 = det(A(1:2,1:2)); if abs(D33) < eps, D33 = 0; end

% Erkennung des Typs des Kegelschnitts an Hand der Matrix A
%
% Ellipse:   D33 >  0
% Kreis:     D33 >  0 & A(1,1) == A(2,2) & A(2,1) == 0
% Parabel:   D33 == 0
% Hyperbel:  D33 <  0
switch sign(D33) % Signum-Funktion erledigt die Unterscheidung bezglich D33
case 1
   if ( abs(A(1,1)-A(2,2))<eps & abs(A(2,1))<eps ) % eps wegen numerischer Ungenauigkeit
      disp('Koeffizientenmatrix fr einen Kreis:');
   else
      disp('Koeffizientenmatrix fr eine Ellipse:');
   end   
case 0
   disp('Koeffizientenmatrix fr eine Parabel:');
case -1
   disp('Koeffizientenmatrix fr eine Hyperbel:');
end
disp(' '); disp(A);
disp(['Determinante:      ',num2str(D)]);
disp(' '); disp(['Unterdeterminante: ',num2str(D33)]);

% Festlegen des Bereichs der x-Werte an Hand der Maximum- und Minimumwerte der Daten 
xmin = min(xd); xmax = max(xd); xdel = xmax - xmin;
% Hinzufgen eines Bereichs auerhalb der Daten
xfac = 0.4; xmin = xmin - xdel*xfac; xmax = xmax + xdel*xfac;
x = linspace(xmin,xmax,500);

% Bestimmung jener Werte von x, bei denen die Lsungen der quadratischen Gleichung
%  a*y^2 + b(x)*y + c(x) = 0
% von komplex zu reell wechseln.
%  Dies ist der Fall, wenn die Diskriminate identisch 0 wird.
%  Damit erhlt man eine quadratische Gleichung fr x. 
a = 4*A(1,2)^2 - 4*A(1,1)*A(2,2); if abs(a) < eps, a = 0; end
b = 8*A(1,2)*A(2,3) - 8*A(2,2)*A(1,3); if abs(b) < eps, b = 0; end
c = 4*A(2,3)^2 - 4*A(2,2)*A(3,3);
% Lsung der quadratischen Gleichung fr x, bzw. im Falle a=0 der linearen Gleichung.
%  Nicht existierende Lsungen werden dabei auf NaN gesetzt.
[x1,x2] = quadgl(a,b,c);

% Ausgabe
disp(' '); disp('Nullstellen der Diskriminante');
if ~isnan(x1), disp([' x1 = ',num2str(x1)]); end
if ~isnan(x2), disp([' x2 = ',num2str(x2)]); end

% Falls die beiden Lsungen innerhalb des x-Wertebereichs liegen und reell sind, werden
%  sie so eingefgt, dass sie den jeweils nchstliegenden Wert ersetzen.
% Dies stellt sicher, dass die erhaltenen Kurven keine fehlenden Teile haben.
if ( x1>min(x) & x1<max(x) & imag(x1)==0), x(abs(x-x1) == min(abs(x-x1))) = x1; end
if ( x2>min(x) & x2<max(x) & imag(x1)==0), x(abs(x-x2) == min(abs(x-x2))) = x2; end

% Lsen der quadratischen Gleichung a*y^2 + b(x)*y + c(x) = 0
%  fr alle x-Werte.
% Je nach x-Wert liefert das komplexe oder rein reelle Lsungen, wobei spter nur die 
%  rein reellen Werte interessant sind.
if abs(A(2,2)) >= eps, ax = A(2,2)*ones(size(x)); else, ax = zeros(size(x)); end
bx = 2*A(2,3) + 2*A(1,2)*x;
cx = A(1,1)*x.^2 + 2*A(1,3)*x + A(3,3);
[y1,y2] = quadgl(ax,bx,cx);

% Hinzufgen der Kurven zu den Daten
% Es werden nur diejenigen Lsungen geplottet, deren Imaginrteil null ist.
epsi = 1.e-6; % Empfohlene "numerische" Grenze um geschlossene Kurven zu erhalten

hold on; % Hinzufgen

xp1 = x; yp1 = y1; % Erste Lsung der quadratischen Gleichung fr y
xp1(abs(imag(y1))>epsi) = NaN; % Werte mit NaN (Not a Number) werden nicht geplottet
yp1(abs(imag(y1))>epsi) = NaN;
plot(xp1,real(yp1),'b');

xp2 = x; yp2 = y2; % Zweite Lsung der quadratischen Gleichung fr y
xp2(abs(imag(y2))>epsi) = NaN;
yp2(abs(imag(y2))>epsi) = NaN;
plot(xp2,real(yp2),'k');
legend('yd','y1','y2',2);
hold off; % Beenden des Hinzufgens

% Setzen der Limits fr die y-Achse
% Dies ist ntig, da es auf Grund numerischer Ungenauigkeiten im Falle der Parabel
% in Spezialfllen irrelevante Lsungen auerhalb des Datenbereichs gibt.
ymin = min(yd); ymax = max(yd); ydel = ymax - ymin;
yfac = 0.4; ymin = ymin - ydel*yfac; ymax = ymax + ydel*yfac;
y = linspace(ymin,ymax,500);
set(gca,'Ylim',[ymin,ymax]);
xlabel('x'); ylabel('y');

% Darstellung der Real- und Imaginrteile der Lsungen 
%  in einer weiteren Darstellung
fig2 = figure(2); clf;
plot(x,real(y1),x,imag(y1),x,real(y2),x,imag(y2));
legend('Re(y1)','Im(y1)','Re(y2)','Im(y2)',2);
set(gca,'Xlim',[xmin,xmax]);
set(gca,'Ylim',[ymin,ymax]);
xlabel('x'); ylabel('Re(y), Im(y)');

% Mache die fig1 zur aktuellen Zeichnung
figure(1);