function [t,p,o]=pendel(method,om,kappa,p0,o0,f0,fomega,fphase,numper,numdat,solver)
% Lsung der Schwingungsgleichung fr das Pendel
%
% Input:    method Methode (l: linear, e: exact)
%           om     Grundfrequenz der lineare Gleichung 
%           kappa  Dmpfungskonstante
%           p0     Anfangswinkel
%           o0     Anfangswinkelgeschwindigkeit
%           f0
%           numper Anzahl der Perioden der linearen Gleichung
%           numdat Anzahl der Daten pro Periode
%           solver Lsungsroutine (ode45,, eulersol, ...)
%
% Output:   t      Zeitvektor
%           p      Vektor der phi-Werte   (Winkel)
%           o      Vektor der omega-Werte (Winkelgeschwindigkeit)
%
% Autor: Winfried Kernbichler   23.01.2000

% Globale Variable zur Kommunikation mit dem Unterprogramm pendeleq
global OM2 KAPPA METHOD F0 FOMEGA FPHASE
OM2    = om^2;
KAPPA  = kappa;
METHOD = method;
F0     = f0;
FOMEGA = fomega;
FPHASE = fphase;

% Vorbereitung des Zeitvektors
tau0 = 2*pi/sqrt(om^2);           % Periodendauer
tanf = 0;                         % Anfangszeit
tend = numper*tau0;               % Endzeit
tanz = numper*numdat;             % Gesamtanzahl der Punkte
tinp = linspace(tanf,tend,tanz);  % Zeitvektor

% Anfangswerte
x0 = [p0;o0];

% Lsung mit feval, da verschiedene Programme benutzt werden knnen.
%  Wenn zB. die Variable solver = 'ode45' ist dann bedeutet
%  feval(solver,'pendeleq',tinp,x0) das gleiche wie
%  ode45('pendeleq',tinp,x0)
[t,x] = feval(solver,'pendeleq',tinp,x0);

% Outputvektoren
% t: direkt vom Solver
% phi und omega: aus den Spalten des Arrays x
p = x(:,1);
o = x(:,2);

% Lschen der globalen Variablen
clear global OM2 KAPPA METHOD
