function pendelplot(t,p,o,tail,numfig)
% Pendelanimation in Realzeit
% Input:  t      Zeit-Vektor
%         p      Phi-Vektor
%         o      Omega-Vektor
%         tail   Lnge des Tails
%         numfig Figurenummer
%
% Autor Winfried Kernbichler   23.01.2000

% Inputberprfung
if nargin < 3, error('Zuwenig Input Parameter'); end
if nargin < 4, tail = 50;  end
if nargin < 5, numfig = 1; end

c1 = min(size(t))*min(size(p))*min(size(o)) == 1;      % Alle drei Vektoren 
c2 = length(t) == length(p) & length(t) == length(o);  % gleicher Lnge
if ~(c1 & c2), error('Arrays falsche Groesse'); end

% Korrektor des Winkels -pi <= p <= pi
p = atan2(sin(p),cos(p));
% Wo die Sprnge im Winkel diff(p)>3/2*pi wird der Wert auf NaN gesetzt
% Dadurch gibt es dann keine Striche im Plot
dp = abs(diff(p)); pc = p; pc(dp>3/2*pi)=NaN;

% Endposition des Pendels
x = sin(p); y = -cos(p);

% Grenzen
lt = length(t);
tmin = t(1);   tmax = t(end);
pmin = min(p); pmax = max(p);
omin = min(o); omax = max(o);

% ffnen der Figure und erstellen von 4 Subplots
fig = figure(numfig); clf;
set(fig,...
   'Name','Animation des Mathematischen Pendels',...
   'NumberTitle','off','MenuBar','none',...
   'Resize','Off','Units','normalized',...
   'Position',[0.05 0.05 .85 .85]);
np = 4; for ip = 1:np, ax(ip) = subplot(2,2,ip); end

axes(ax(1));              % Plot phi versus time
 lh(1)=line(t,pc);        %  Kurve
 ph(1)=line(t(1),p(1));   %  Erster Punkt fr Animation
 th(1)=line(t(1),p(1));   %  Erster Punkt fr Tail
 axis([tmin tmax -pi pi]);
 xlabel('t [sec]'); ylabel('\phi');
axes(ax(2));              % Plot omega versus time
 lh(2)=line(t,o);
 ph(2)=line(t(1),o(1));
 th(2)=line(t(1),o(1));
 axis([tmin tmax omin omax]);
 xlabel('t [sec]'); ylabel('\Omega');
axes(ax(3));              % Plot omega versus phi
 lh(3)=line(pc,o);
 ph(3)=line(p(1),o(1));
 th(3)=line(p(1),o(1));
 axis([-pi pi omin omax]);
 xlabel('\phi'); ylabel('\Omega');
axes(ax(4));              % Plot Pendel
 lh(4)=line([0 x(1)],[0 y(1)],'EraseMode','xor','LineWidth',4,'Color','red');
 axis([-1.2 1.2 -1.2 1.2]); 
 axis square;
 set(ax(4),'XTick',[],'YTick',[]);
 xlabel('x'); ylabel('y');
 
% Einstellungen fr Animationspunkte (ph) und Tail (th) 
set(ph(1:3),'EraseMode','xor','Marker','.','MarkerSize',20,'Color','red');
set(th(1:3),'EraseMode','xor','Color',[1 0 0],'LineWidth',3);
 
anim=strcmp('j', dinput('Animation:','s','j',{'j','n'}) ); % Animation?
 
figure(fig); % Figure im Vordergrund
while anim
   t0 = clock;            % Uhrzeit
   for it = 2:1:lt        % Durchfhren der Animation
      tc=etime(clock,t0); % Zeitdifferenz in Sekunden
      while tc<t(it), tc=etime(clock,t0); end % Warteschleife bis zur "richtigen" Zeit
      set(ph(1),'XData',t(it),'YData',p(it));
      set(th(1),'XData',t(max(it-tail,1):it-1),'YData',pc(max(it-tail,1):it-1));
      set(ph(2),'XData',t(it),'YData',o(it));
      set(th(2),'XData',t(max(it-tail,1):it-1),'YData',o(max(it-tail,1):it-1));
      set(ph(3),'XData',p(it),'YData',o(it));
      set(th(3),'XData',pc(max(it-tail,1):it-1),'YData',o(max(it-tail,1):it-1));
      set(lh(4),'XData',[0 x(it)],'YData',[0 y(it)]);
      drawnow;
   end
   set(ph(1),'XData',t(1),'YData',p(1));         % Rcksetzen der Punkte
   set(ph(2),'XData',t(1),'YData',o(1));
   set(ph(3),'XData',p(1),'YData',o(1));
   set(th(1:3),'XData',[],'YData',[]);           % Lschen des Tails
   set(lh(4),'XData',[0 x(1)],'YData',[0 y(1)]); % Rcksetzen des Pendels
   
   anim=strcmp('j', dinput(' Nochmals:','s','n',{'j','n'}) ); % Wiederholung?
   figure(fig);
end
close(fig); % Schlieen der Figure