function schwebung(f1,f2,time)
% Die Funktion schwebung erzeugt einen plot der Grundschwingungen und der Schwebung
% Input: f1 und f2 - Frequenzen
%        time      - Zeitinterval (in Einheiten von 2*pi)
% 
% Autor: Winfried Kernbichler     28.11.1999

% berprfung der Inputvariablen (Setzen der Defaultwerte)
if (nargin < 1), f1 = 2.0; end
if (nargin < 2), f2 = 2.2; end
if (nargin < 3), time = 10; end

% Funktionsberechnung
ts = 0;  
te = time*2*pi;
td = pi/200;

t = ts:td:te;
y1 = sin(f1*t);
y2 = sin(f2*t);
ys = (y1 + y2) / 2;

% Setzen der Defaultwerte und ffnen der Figur 
setmyfig(1);
fig1 = figure(1);
set(fig1,'Name','Schwebung');
disp('PAUSE MODE');pause;

% Definition von 4 Achsensystemen
% ax1: Beschriftung
% ax2: Schwebung
% ax3: Funktion 1
% ax4: Funktion 2
ax1 = axes('Position',[0.05 0.05 0.10 0.90]); % Balken links
  set(ax1,'Visible','off');
ax2 = axes('Position',[0.25 0.05 0.70 0.40]); % Balken unten
 ax2yl = ylabel('Schwebung, \itf\rm(\itt\rm)');
ax3 = axes('Position',[0.25 0.55 0.34 0.40]); % Balken oben links
 ax3yl = ylabel('Signale, \itf\rm(\itt\rm)');
ax4 = axes('Position',[0.61 0.55 0.34 0.40]); % Balken oben rechts
 set(ax4,'YTickLabel',[]);
 
set([ax2,ax3,ax4],'XTick',[]); % Vorerst keine Tickmarks in x-Richtung
set([ax2,ax3,ax4],'Box','on'); % Box um Achsensystem
disp('PAUSE MODE');pause;

% Setzen der Tickmarks und Label in y- und x-Richtung
set([ax2,ax3,ax4],'YLim',[-1.2 1.2]); % Etwas ber 1 hinaus
set([ax2,ax3,ax4],'XLim',[ts-pi te+pi]); 
tdv = 5*(2*pi); % Nur 5-fache von 2*pi
t_tick = ts:tdv:te;
set([ax2,ax3,ax4],'XTick',t_tick)
t_tick_label = round(t_tick/(2*pi)); % Vielfache von 2*pi
set([ax2,ax3,ax4],'XTickLabel',t_tick_label)
disp('PAUSE MODE');pause;

% Zeichnen der Kurven
l2 = line(t,ys,'Parent',ax2,'Color','red');
l3 = line(t,y1,'Parent',ax3,'Color','blue');
l4 = line(t,y2,'Parent',ax4,'Color','green');
disp('PAUSE MODE');pause;

% Zeichnen der Legenden
axes(ax2);leg2 = legend('(\itf\rm_{1}+\itf\rm_{2})/2',1);
axes(ax3);leg3 = legend('\itf\rm_{1}=\itsin\rm(2\pi\omega_{1}\itt\rm)',1);
axes(ax4);leg4 = legend('\itf\rm_{1}=\itsin\rm(2\pi\omega_{2}\itt\rm)',1);
set([leg2,leg3,leg4],'Color',[1 1 0.7]); % Hintergrundfarbe fr alle Legenden
set(leg2,'Position',get(leg2,'Position')+[0 0.05 0 0]); % Positionsverschiebung
set(leg3,'Position',get(leg3,'Position')+[0 0.05 0 0]);
set(leg4,'Position',get(leg4,'Position')+[0 0.05 0 0]);
disp('PAUSE MODE');pause;

% Hinzufgen von Text in der ersten Achse
str1(1) = {'\bfberlagerung von Schwingungen\rm'};
str1(2) = {['\omega_{1} = ',num2str(f1),'       \omega_{2} = ',num2str(f2)]};
t1 = text(0.5,0.5,str1,'Parent',ax1,'Rotation',90,'Color','red','FontSize',20);
set(t1,'VerticalAlignment','middle');
set(t1,'HorizontalAlignment','center');
disp('PAUSE MODE');pause;

% Beenden
print(fig1,'-dmeta'); % Clipboard Windows Metafile Format
print(fig1,'-dtiff','schwebung.tif');  % Speichern als TIFF-File
print(fig1,'-depsc2','-r600','schwebung.eps'); % Speichern als EPS-File (600dpi)
close(fig1);
setmyfig(0);