function [mat,p] = spezmat(art,m,n,o,inverse)
% Darstellung spezieller Matrizen
% spezmat(art,m,n,o,inverse)
% Aufruf spezmat('liste') liefert mgliche Arten
% m: Gre der quadratischen Matrizen
% n, o: Diverse Breiten
% inverse: falls inverse Darstellung gewnscht ist 'inv'

% Autor: Winfried Kernbichler  14.11.1999

% Vervollstndigung des Inputs
if (nargin <= 0), art = 'Schach'; end
if (nargin <= 1), m = 8; end
if (nargin <= 2), n = 4; end
if (nargin <= 3), o = n; end
if (nargin <= 4), inverse = 'no'; end

% Wechsel zu Kleinschreibung
% Damit ist als Eingabe schach, Schach oder SCHACH mglich
sw = lower(art);
in = lower(inverse);

% Erzeugung der Matrizen und der Titel
switch sw
case 'schach'
   mat = cut( repmat( eye(2), ceil(m/2), ceil(m/2) ), m );
   tit = ['Schachbrett',' m=',num2str(m)];
case 'schachblock'
   mat = cut( repmat( blkdiag(ones(n),ones(n)), ceil(m/n), ceil(m/2) ), m );
   tit = ['Schachblock',' m=',num2str(m),' n=',num2str(n)];
case 'diag'
   mat = cut( repmat( eye(n), ceil(m/n), ceil(m/n) ), m );   
   tit = ['Diagonalen',' m=',num2str(m),' n=',num2str(n)];
case 'flipdiag' % Rekursiver Aufruf!!!!
   mat = flipud( spezmat('diag',m,n,o) );   
   tit = ['Gespiegelte Diagonalen',' m=',num2str(m),' n=',num2str(n)];
case 'sumdiag' % Rekursiver Aufruf!!!!
   mat = spezmat('diag',m,n,o) | spezmat('flipdiag',m,n,o);   
   tit = ['Summe der Diagonalen',' m=',num2str(m),' n=',num2str(n)];
case 'linien'
   mat = cut( repmat([ones(n,m);zeros(o,m)],ceil(m/(n+o)),1), m);
   tit = ['Linien',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
case 'reihen'
   mat = cut( repmat([ones(n,m);zeros(o,m)],ceil(m/(n+o)),1), m)';
   tit = ['Reihen',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
case 'netz' % Rekursiver Aufruf!!!!
   mat = spezmat('linien',m,n,o) | spezmat('reihen',m,n,o);
   tit = ['Netz',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
case 'dlinien'
   [X,Y] = meshgrid(1:m);
   mat = mod(X+Y-2,n+o)+1;
   % Array wo in den Nebendiagonalen immer die gleichen Werte stehen
   % z.B. fr n+o = 5: 0 1 2 3 4 0 1 2 3 4 ....
   mat(mat>n)  = 0; % ersetzt obiges durch 0
   mat(mat~=0) = 1; % und 1
   tit = ['Diagonale Linien',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
case 'dreihen'
   mat = flipud( spezmat('dlinien',m,n,o) ); % Rekursiver Aufruf!!!!
   tit = ['Diagonale Reihen',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
case 'dnetz' % Rekursiver Aufruf!!!!
   mat = spezmat('dlinien',m,n,o) | spezmat('dreihen',m,n,o);
   tit = ['Diagonales Netz',' m=',num2str(m),' n=',num2str(n),' o=',num2str(o)];
otherwise
   mat = spezmat('schach',m);
   tit = ['Schachbrett',' m=',num2str(m)];
   fprintf(1,'Gltige Typen: \n\n');
   fprintf(1,'schach       : Schachbrett \n');
   fprintf(1,'schachblock  : Schachbrett mit greren Feldern \n');
   fprintf(1,'diag         : Diagonalen \n');
   fprintf(1,'flipdiag     : Gespiegelte Diagonalen \n');
   fprintf(1,'sumdiag      : Summe der Diagonalen \n');
   fprintf(1,'linien       : Linien \n');
   fprintf(1,'reihen       : Reihen \n');
   fprintf(1,'netz         : Netz \n');
   fprintf(1,'dlinien      : Diagonale Linien \n');
   fprintf(1,'dreihen      : Diagonale Reihen \n');
   fprintf(1,'dnetz        : Diagonales Netz \n');
   fprintf(1,'\n\n');
   fprintf(1,'Option inv als 5ter Parameter fr inverse Darstellung\n\n');
end

% Eventuell inverse Darstellung
switch in
case {'inv','inverse','i','in'}
   mat = ~mat;
   tit = ['Inv. ',tit];
end

% Darstellung
p = imagesc(mat);
set(gca,'XTick',[],'YTick',[]);
axis square;
title(tit);
if isempty(mat(mat==0))
   colormap([0 0 0;0 0 0]);
else	
   colormap([1 1 1;0 0 0]);
end
   
function res = cut(mat,m)
% Subfunktion zum Ausschneiden
% Funktioniert nur in diesem Kontext
res = mat(1:m,1:m);
